<!-- omit in toc -->
# BioMCP 🚀

<div align="center">

<strong>The fast, Pythonic way to build MCP servers for bioinformatics.</strong>

[![PyPI - Version](https://img.shields.io/pypi/v/biomcp.svg)](https://pypi.org/project/biomcp)
[![Tests](https://github.com/biomcp/biomcp/actions/workflows/run-tests.yml/badge.svg)](https://github.com/biomcp/biomcp/actions/workflows/run-tests.yml)
[![License](https://img.shields.io/github/license/biomcp/biomcp.svg)](https://github.com/biomcp/biomcp/blob/main/LICENSE)


</div>